NLSL: ipar.f90 Source File

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

ipar.f90
Go to the documentation of this file.
1 c VERSION 1.0 12/17/88
2 c*********************************************************************
3 c
4 c SUBROUTINE IPAR
5 c ===============
6 c
7 c This integer function subroutine returns the value -1
8 c if its argument is odd, and +1 if it is even.
9 c
10 c*********************************************************************
11 c
12 integer function ipar(num)
13 c
14 integer num
15 c
16 c#####################################################################
17 c
18 if (mod(num,2).eq.0) then
19 ipar=1
20 else
21 ipar=-1
22 end if
23 return
24 end
ipar
integer function ipar(num)
Definition: ipar.f90:13